slepc-3.18.0 2022-10-01
Report Typos and Errors

# STSetUp

Prepares for the use of a spectral transformation.

### Synopsis

    #include "slepcst.h"
    PetscErrorCode STSetUp(ST st)

Collective on st

### Input Parameter

| st | - the spectral transformation context

### See Also

STCreate(), STApply(), STDestroy()

### Level

advanced

### Location

src/sys/classes/st/interface/stsolve.c
Index of all ST routines
Table of Contents for all manual pages
Index of all manual pages